@@ -476,8 +476,8 @@ static void learn(VCC *vcc,unsigned long ip,struct sockaddr_atmsvc *addr)
 	if (vcc) {
 	    entry = vcc->entry;
 	    if (!entry->itf) Q_REMOVE(unknown_incoming,entry);
-	    else if (entry->ip && entry->ip != ip && (entry->flags & ATF_PERM))
-		  {
+	    else if (entry->ip && entry->ip != ip && (entry->flags & ATF_PERM)
+		  && !(entry->flags & ATF_ARPSRV)) {
 		    diag(COMPONENT,DIAG_ERROR,"ignoring attempt to change IP "
 		      "address of permanent entry (to %d.%d.%d.%d)",ipp[0],
 		      ipp[1],ipp[2],ipp[3]);
