@@ -381,7 +381,17 @@ void poll_loop(void)
 	    FD_SET(entry->vccs->fd,&rset);
 	    if (entry->vccs->fd >= fds) fds = entry->vccs->fd+1;
 	}
-	ret = select(fds,&rset,&cset,&cset,next_timer());
+	ret = select(fds,&rset,&cset,NULL,next_timer());
+fprintf(stderr,"select = %d\n",ret);
+#if 0
+{
+  int i;
+  for (i = 0; i < sizeof(rset); i++)
+   fprintf(stderr,"%02x:%02x ",((unsigned char *) &rset)[i],
+    ((unsigned char *) &cset)[i]);
+  fprintf(stderr,"\n");
+}
+#endif
 	if (ret < 0) {
 	    if (errno != EINTR) perror("select");
 	}
@@ -407,7 +417,7 @@ void poll_loop(void)
 		if (FD_ISSET(entry->vccs->fd,&rset)) recv_vcc(entry->vccs);
 	    }
 	    expire_timers();
-	      /* expire timers after handling messges to make sure we don't
+	      /* expire timers after handling messages to make sure we don't
 		 time out unnecessarily because of scheduling delays */
 	}
 	dump_all();
