@@ -1,6 +1,6 @@
 /* znth.c - ZN122x timestamp adjustments history */
 
-/* Written 1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1996,1997 by Werner Almesberger, EPFL-LRC */
 
 
 #include <stdlib.h>
@@ -9,8 +9,7 @@
 #include <sys/ioctl.h>
 #include <sys/time.h>
 #include <linux/atm.h>
-
-#include "/usr/src/linux/drivers/atm/zatm.h"
+#include <linux/atm_zatm.h>
 
 
 int main(int argc,char **argv)
