@@ -1,11 +1,9 @@
 /*
- * ilmid.c - Ilmi agent daemon
+ * ilmi.c - ILMI demon
  *
  * Written by Scott W. Shumate
  * 
- * Copyright (c) 1995 Telecommunications & Information
- * Sciences Laboratory, The University of Kansas 
- * All Rights Reserved.
+ * Copyright (c) 1995-97 All Rights Reserved.
  * 
  * Permission to use, copy, modify and distribute this
  * software and its documentation is hereby granted,
@@ -17,19 +15,10 @@
  * acknowledged in any publications resulting from using
  * the software.
  * 
- * TISL ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
- * CONDITION AND DISCLAIMS ANY LIABILITY OF ANY KIND FOR
+ * I ALLOW FREE USE OF THIS SOFTWARE IN ITS "AS IS"
+ * CONDITION AND DISCLAIM ANY LIABILITY OF ANY KIND FOR
  * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS
  * SOFTWARE.
- * 
- * Telecommunications & Information Science Lab
- * 2291, Irving Hill Road Lawrence, KS 66046
- * (913)-864-7757
- * http://www.tisl.ukans.edu
- * 
- * The development of this software was generously
- * supported by research grants from Sprint corporation,
- * and we would like to express our thanks.
  */
 
 /* Change Log:
@@ -51,7 +40,8 @@
 #include "io.h"
 #include "atmd.h"
 #include "mib.h"
-#include "netprefix.h"
+#include "atmf_uni.h"
+#include "sysgroup.h"
 
 #define RESPONSE_TIMEOUT 2
 #define POLL_PERIOD 15
@@ -79,8 +69,9 @@ void ilmi_loop(int fd, int itf)
   AsnOid *set_oid, *netprefix_oid, *esi_oid;
   VarBind *varbind;
   struct timeval timeout;
-  IlmiState state, new_state; 
+  IlmiState state, new_state;
 
+  resetUpTime();
   poll_message = create_poll_message();
   set_message = create_set_message();
   set_oid = &((VarBind *) FIRST_LIST_ELMT(set_message->data->a.set_request->variable_bindings))->name;
@@ -101,6 +92,7 @@ void ilmi_loop(int fd, int itf)
 	case RESTART:
 	  deleteNetPrefix();
 	  diag(COMPONENT, DIAG_INFO, "sending cold-start");
+	  coldstart_message->data->a.trap->time_stamp = accessUpTime();
           send_message(fd, coldstart_message);
           no_response = 0;
 
@@ -168,7 +160,7 @@ void ilmi_loop(int fd, int itf)
 			  case RESTART:
                           case VERIFY:
 			    if(in_message->data->a.get_response->error_status == NOERROR &&
-			       AsnOidMember(&varbind->name, &atmAddressStatus))
+			       AsnOidCompare(&atmAddressStatus, &varbind->name) == AsnOidRoot)
 			      new_state = RESTART;
 			    else
 			      new_state = NET_PREFIX;
@@ -177,7 +169,7 @@ void ilmi_loop(int fd, int itf)
 			  case ADDRESS:
 			    if(in_message->data->a.get_response->error_status == NOERROR)
 			      {
-				diag(COMPONENT, DIAG_WARN, "ATM address registered");
+				diag(COMPONENT, DIAG_INFO, "ATM address registered");
 				update_nsap(itf, netprefix_oid, esi_oid);
 				no_response = 0;
 				new_state = POLL;
@@ -188,7 +180,7 @@ void ilmi_loop(int fd, int itf)
 			    
 			  case POLL:
 			    if(in_message->data->a.get_response->error_status == NOERROR &&
-			       AsnOidEqual(&varbind->name, set_oid))
+			       AsnOidCompare(&varbind->name, set_oid) == AsnOidEqual)
                             {
 			       no_response = 0;
                                new_state = IDLE;
@@ -309,7 +301,7 @@ int main(int argc, char *argv[])
   if(argc != optind)
     usage(argv[0]);
 
-  diag(COMPONENT, DIAG_WARN, "Linux ATM ILMI, version %s", VERSION);
+  diag(COMPONENT, DIAG_INFO, "Linux ATM ILMI, version %s", VERSION);
 
   if(bg)
     {
