@@ -3,9 +3,7 @@
  *
  * Written by Scott W. Shumate
  * 
- * Copyright (c) 1995 Telecommunications & Information
- * Sciences Laboratory, The University of Kansas 
- * All Rights Reserved.
+ * Copyright (c) 1995-97 All Rights Reserved.
  * 
  * Permission to use, copy, modify and distribute this
  * software and its documentation is hereby granted,
@@ -17,19 +15,10 @@
  * acknowledged in any publications resulting from using
  * the software.
  * 
- * TISL ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
+ * I ALLOW FREE USE OF THIS SOFTWARE IN ITS "AS IS"
  * CONDITION AND DISCLAIMS ANY LIABILITY OF ANY KIND FOR
  * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS
  * SOFTWARE.
- * 
- * Telecommunications & Information Science Lab
- * 2291, Irving Hill Road Lawrence, KS 66046
- * (913)-864-7757
- * http://www.tisl.ukans.edu
- * 
- * The development of this software was generously
- * supported by research grants from Sprint corporation,
- * and we would like to express our thanks.
  */
 
 #include <sys/socket.h>
@@ -128,7 +117,7 @@ void update_nsap(int itf, AsnOid *netprefix, AsnOid *esi)
 
   n = 0;
   if (req.length && atm_equal(&addr, &ouraddr[0], ATM_ESA_LEN, 0)) {
-    diag(COMPONENT, DIAG_WARN, "Primary ATM Address did not change");
+    diag(COMPONENT, DIAG_INFO, "Primary ATM Address did not change");
     n = 1;
   }
 
@@ -149,7 +138,7 @@ void update_nsap(int itf, AsnOid *netprefix, AsnOid *esi)
 
 	  atm2text(buffer,MAX_ATM_ADDR_LEN+1,(struct sockaddr *) &addr, A2T_PRETTY);
 
-	  diag(COMPONENT, DIAG_WARN, "Primary ATM Address %s added local", buffer);
+	  diag(COMPONENT, DIAG_INFO, "Primary ATM Address %s added local", buffer);
 	
 	  for (n = 0; n < m/sizeof(addr); n++) {
 
@@ -164,7 +153,7 @@ void update_nsap(int itf, AsnOid *netprefix, AsnOid *esi)
 		  if (ioctl(fd, ATM_ADDADDR, &req) < 0)
 		    diag(COMPONENT, DIAG_ERROR, "ioctl ATM_ADDADDR: %s", strerror(errno));
 	          else	
-		    diag(COMPONENT, DIAG_WARN, "Extra   ATM Address %s added local", buffer);
+		    diag(COMPONENT, DIAG_INFO, "Extra   ATM Address %s added local", buffer);
 
 	  }
   }	     	
