@@ -96,7 +96,6 @@ extern int errno;
 
 typedef struct _conn_t_ {
   int fd;                  /* Socket connected to this connection */
-  CONN_INFO *info;
   unsigned long age_limit; /* In seconds. If this SVC is idle (no traffic) 
 			      for longer than the age limit, it will be 
 			      torn down.  If the age limit is specified 
@@ -554,7 +553,7 @@ svcinit_conn_info(CONN_INFO *p_svc_conn_info)
 void
 conn_call_callbacks(void)
 {
-  Conn_t *conn, *c_tmp;
+  Conn_t *conn;
   Sap_client_t *sap;
   
   conn = connlist;
@@ -581,7 +580,6 @@ conn_call_callbacks(void)
       conn = conn->next;
     } else if (conn->status == RELEASED) {
       EVENT(EM_DEBUG,("Conn_call_callbacks, released conn %p\n",conn));
-#if 0
       conn->status = NOTIFIED;
       sap = (Sap_client_t *)conn->sap_handle;
       sap->vc_notify_callback(conn->conn_context,
@@ -590,25 +588,7 @@ conn_call_callbacks(void)
 			      CAUSE_NORMAL,
 			      0,
 			      (conn->type==WEMADE)?TRUE:FALSE);
-      c_tmp=conn->next;
-      close(conn->fd);
-      /* Remove conn from list */
-      list_remove_conn(conn);
-      if (conn->conn_info)
-	mem_free(EINST, conn->conn_info);
-      mem_free(EINST,conn);
-      conn=c_tmp;
-#endif
-      conn->status = NOTIFIED;
-      c_tmp = conn->next;
-      sap = (Sap_client_t *)conn->sap_handle;
-      sap->vc_notify_callback(conn->conn_context,
-			      conn,
-			      CONN_RELEASE,
-			      CAUSE_NORMAL,
-			      0,
-			      (conn->type==WEMADE)?TRUE:FALSE);
-      conn=c_tmp;
+      conn=connlist;
     } else {
       conn = conn->next;
     }
@@ -1004,7 +984,6 @@ list_add_conn(HANDLE sap_handle, HANDLE conn_context, long age_limit,
   
   conn->sap_handle = sap_handle;
   conn->conn_context = conn_context;
-  conn->info = info;
   conn->age_limit = age_limit;
   if (info)
     memcpy(conn->atm_address, info->addr.sas_addr.prv, ATM_ESA_LEN);
