@@ -19,7 +19,7 @@ void conn_get_connecting_fds(fd_set *fds);
 int conn_check_incoming(fd_set *fds);
 int conn_create_listensocket(HANDLE sap_context, HANDLE conn_context,
 			     unsigned short blli_codepoint,
-			     int max_cell_rate,
+			     const char *qos_spec,
 			     HANDLE *p_conn_handle);
 int conn_set_kernel_socket(int fd);
 /*
