@@ -92,18 +92,16 @@ kernel_arp_xmt_callback(struct atmlec_msg *mesg)
   }
 }
 
-static void
-kernel_flush_xmt_callback(struct atmlec_msg *mesg)
+void
+kernel_flush_xmt(unsigned char *to_pass)
 {
   LA_ELAN_CONTEXT *p_elan;
-  ADDR_ATM *to_pass;
   UINT32 dumb;
 
-  to_pass = (ADDR_ATM*)mesg->content.normal.atm_addr;
-
   utl_list_traverse(lec_arp_context.elan_list, p_elan) {
-    lec_arp_context.flush_xmt_callback(p_elan->lc_elan_handle, *to_pass,&dumb);
-    kernel_sendmsg(l_flush_tran_id, mesg->content.normal.mac_addr,NULL,
+    lec_arp_context.flush_xmt_callback(p_elan->lc_elan_handle, to_pass,&dumb);
+    EVENT(EM_DEBUG,("Setting flush transaction id to %lx\n",dumb));
+    kernel_sendmsg(l_flush_tran_id, NULL, to_pass,
 		   NULL, dumb);
   }
 }
@@ -135,7 +133,6 @@ la_create (HANDLE lc_handle, ARP_XMT_CALLBACK arp_xmt_callback,
   utl_list_init(lec_arp_context.elan_list);
 
   kernel_register_callback(l_arp_xmt, kernel_arp_xmt_callback);
-  kernel_register_callback(l_flush_xmt, kernel_flush_xmt_callback);
   kernel_register_callback(l_svc_setup, kernel_svc_setup_xmt_callback);
 
   *p_la_handle = (HANDLE)&lec_arp_context;
@@ -220,9 +217,9 @@ la_config(HANDLE la_elan_handle, LAN_TYPE lan_type,
   conf_mesg.maximum_unknown_frame_count = max_unknown_frame_count;
   conf_mesg.max_unknown_frame_time = max_unknown_frame_time;
   conf_mesg.max_retry_count = max_retry_count;
-  conf_mesg.aging_time = aging_time * 1000;
-  conf_mesg.forward_delay_time = forward_delay_time * 1000;
-  conf_mesg.arp_response_time = le_arp_response_time * 1000;
+  conf_mesg.aging_time = aging_time;
+  conf_mesg.forward_delay_time = forward_delay_time;
+  conf_mesg.arp_response_time = le_arp_response_time;
   conf_mesg.flush_timeout = flush_timeout;
   conf_mesg.path_switching_delay = path_switching_delay;
   kernel_sendmsg(l_config, NULL, NULL, &conf_mesg, 0);
@@ -252,11 +249,11 @@ la_arp_update(HANDLE    la_elan_handle,
 
 void 
 la_flush_complete(HANDLE la_elan_handle,
-		  ADDR_ATM addr_atm,
 		  UINT32   tran_id)
 {
+  EVENT(EM_DEBUG,("Flush complete for tran_id %lx\n", tran_id));
   kernel_sendmsg(l_flush_complete, NULL,
-		 (unsigned char *)&addr_atm, NULL, tran_id);
+		 NULL, NULL, tran_id);
 }
 
 void 
