@@ -24,7 +24,7 @@
 /*
  * Include file for timer funcs not used in DIGITAL's code
  *
- * $Id: timers.h,v 1.2 1996/04/25 19:42:13 carnil Exp carnil $
+ * $Id: timers.h,v 1.3 1996/08/06 14:14:11 carnil Exp carnil $
  *
  */
 /* Global includes */
@@ -36,10 +36,13 @@
 void timer_call_callback(HANDLE timer_handle);
 struct timeval* timer_get_expiration(HANDLE timer_handle);
 HANDLE timer_find_soonest(void);
-
+void timer_usage(void);
 /*
  *
  * $Log: timers.h,v $
+ * Revision 1.3  1996/08/06 14:14:11  carnil
+ * Cleaning up
+ *
  * Revision 1.2  1996/04/25 19:42:13  carnil
  * Copyright notice
  *
