@@ -1,7 +1,7 @@
 /* text2qos.c - Converts textual representation of QOS parameters to binary
 		encoding */
 
-/* Written 1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1996,1997 by Werner Almesberger, EPFL-LRC */
 
 
 #include <stdlib.h>
@@ -139,11 +139,33 @@ static int params(const char **text,struct atm_trafprm *a,
 
 int text2qos(const char *text,struct atm_qos *qos,int flags)
 {
-    int traffic_class;
+    int traffic_class,aal;
 
-    if ((traffic_class = fetch(&text,"!none","ubr","cbr",NULL)) < 0) return -1;
+    traffic_class = ATM_NONE;
+    aal = ATM_NO_AAL;
+    do {
+	static const unsigned char aal_number[] = { ATM_AAL0, ATM_AAL5 };
+	int item;
+
+	item = fetch(&text,"!none","ubr","cbr","aal0","aal5",NULL);
+	switch (item) {
+	    case 1:
+	    case 2:
+		traffic_class = item;
+		break;
+	    case 3:
+	    case 4:
+		aal = aal_number[item-3];
+		break;
+	    default:
+		return -1;
+	}
+    }
+    while (*text == ',' ? text++ : 0);
+    if (!traffic_class) return -1;
     if (qos && !(flags & T2Q_DEFAULTS)) memset(qos,0,sizeof(*qos));
     if (qos) qos->txtp.traffic_class = qos->rxtp.traffic_class = traffic_class;
+    if (qos && aal) qos->aal = aal;
     if (!*text) return 0;
     if (params(&text,qos ? &qos->txtp : NULL,qos ? &qos->rxtp : NULL))
 	return -1;
