@@ -1,6 +1,6 @@
 /* atmdump.c - ATM raw cell dumper */
 
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
 
 
 #include <stdlib.h>
@@ -108,7 +108,7 @@ int main(int argc,char **argv)
 		usage(name);
 	}
     if (argc != optind+1) usage(name);
-    if ((s = socket(PF_ATMPVC,SOCK_DGRAM,ATM_AAL0)) < 0) {
+    if ((s = socket(PF_ATMPVC,SOCK_DGRAM,0)) < 0) {
 	perror("socket");
 	return 1;
     }
@@ -116,6 +116,7 @@ int main(int argc,char **argv)
     if (text2atm(argv[optind],(struct sockaddr *) &addr,sizeof(addr),T2A_PVC)
       < 0) usage(name);
     memset(&qos,0,sizeof(qos));
+    qos.aal = ATM_AAL0;
     if (type == -1) {
 	qos.rxtp.traffic_class = ATM_UBR;
 	qos.rxtp.max_sdu = 52;
