@@ -495,7 +495,11 @@ static void handle_error(Q_DSC *dsc,int size,unsigned char *buf,
     PREFIX(report)(Q_ERROR,q_err_msg[type],value);
     PREFIX(report)(Q_ERROR,"[ PC=%d SP=%d RP=%d, pos=%d end=%d ]",*pc-parse,
       *sp,*rp,*pos-buf,*end-buf);
-    error = alloc_t(Q_ERR_DSC);
+    error = malloc(sizeof(Q_ERR_DSC));
+    if (!error) {
+	perror("out of memory");
+	exit(0);
+    }
     error->type = type;
     for (last = &dsc->errors; *last; last = &(*last)->next);
     *last = error;
