@@ -7,13 +7,15 @@
 #include <stdio.h>
 #endif
 #include <stdlib.h>
+#include <stdarg.h>
 #include <string.h>
-#include <netinet/in.h> /* for htonl, ntohl */
+#include <netinet/in.h> /* for htonl */
 
 #include "atmd.h"
 
 #include "sscop.h"
 #include "queue.h"
+#include "pdu.h"
 
 
 /*
@@ -79,35 +81,6 @@
 #define TIMER_IDLE	30000000 /* 30 sec (>> keepalive) */
 
 
-/* SSCOP PDU types, 7.1 */
-
-#define SSCOP_BGN	 1 /* Request Initialization */
-#define SSCOP_BGAK	 2 /* Request Acknowledgement */
-#define SSCOP_BGREJ	 7 /* Connection Reject */
-#define SSCOP_END	 3 /* Disconnect Command */
-#define SSCOP_ENDAK	 4 /* Disconnect Acknowledgement */
-#define SSCOP_RS	 5 /* Resynchronization Command */
-#define SSCOP_RSAK	 6 /* Resynchronization Acknowledgement */
-#define SSCOP_ER	 9 /* Recovery Command */
-#define SSCOP_ERAK	15 /* Recovery Acknowledgement */
-#define SSCOP_SD	 8 /* Sequence Connection-mode Data */
-#define SSCOP_POLL	10 /* Transmitter State Information with request ... */
-#define SSCOP_STAT	11 /* Solicited Receiver State Information */
-#define SSCOP_USTAT	12 /* Unsolicited Receiver State Information */
-#define SSCOP_UD	13 /* Unnumbered User Data */
-#define SSCOP_MD	14 /* Unnumbered Management Data */
-
-
-/* Trailer format macros */
-
-#define SSCOP_TRAIL(type,pad,n) (htonl((n) | ((type) << 24) | ((pad) << 30)))
-#define SSCOP_S_BIT 0x10000000
-#define SSCOP_TYPE(last) ((ntohl(last) >> 24) & 15)
-#define SSCOP_PAD(last) (ntohl(last) >> 30)
-#define SSCOP_N(last) (ntohl(last) & 0xffffff)
-#define SSCOP_S(last) (ntohl(last) & SSCOP_S_BIT)
-
-
 /* Some helper macros */
 
 #define START_TIMER(t) ({ STOP_TIMER(dsc->timer_##t); \
@@ -121,18 +94,6 @@
 #define NORM_TX(v) NORMALIZE((v),dsc->vt_a)
 
 
-/* Helper macros for PDU construction and decomposition */
-
-#define PDU_VARS \
-  unsigned char type; \
-  int length; \
-  int s,ps,r,mr,sq
-#define DECOMPOSE_PDU(dsc,msg,size) decompose_pdu(dsc,msg,size,&type, \
-  &length,&s,&ps,&r,&mr,&sq)
-#define PRINT_PDU(dsc,label,data) print_pdu(dsc,label,type,data,&length, \
-  &s,&ps,&r,&mr,&sq)
-
-
 static const char *pdu_name[] = { "???","BGN","BGAK","END","ENDAK","RS","RSAK",
   "BGREJ","SD","ER","POLL","STAT","USTAT","UD","MD","ERAK" };
 
@@ -141,8 +102,24 @@ static const char *state_name[] = { "Idle","OutConnPend","InConnPend",
   "InRecPend","DataTransReady" };
 
 
-static void maa_error(SSCOP_DSC *dsc,char code,int count)
+static void do_diag(int severity,const char *fmt,...)
 {
+    va_list ap;
+
+    va_start(ap,fmt);
+    vdiag(COMPONENT,severity,fmt,ap);
+    va_end(ap);
+}
+
+
+static void maa_error(void *arg,char code,int count)
+{
+    /*
+     * arg is void * because it's also used in pdu.c, which doesn't know about
+     * SSCOP_DSC
+     */
+    SSCOP_DSC *dsc = arg;
+
     static const char *const msgs[] = {
 	"A:SD PDU","B:BGN PDU","C:BGAK PDU","D:BGREJ PDU","E:END PDU",
 	"F:ENDAK PDU","G:POLL PDU","H:STAT PDU","I:USTAT PDU","J:RS",
@@ -166,94 +143,6 @@ static void maa_error(SSCOP_DSC *dsc,char code,int count)
 }
 
 
-static void print_pdu(SSCOP_DSC *dsc,const char *label,unsigned char type,
-  void *data,const int *length,const int *s,const int *ps,const int *r,
-  const int *mr,const int *sq)
-{
-    int len;
-    int *list;
-
-    switch (type) {
-	case SSCOP_SD:
-	    diag(COMPONENT,DIAG_DEBUG,"%s SD(S=%d,len=%d)",label,*s,*length);
-	    break;
-	case SSCOP_POLL:
-	    diag(COMPONENT,DIAG_DEBUG,"%s POLL(PS=%d,S=%d)",label,*ps,*s);
-	    break;
-	case SSCOP_STAT:
-	    if (*length & 3) {
-		diag(COMPONENT,DIAG_WARN,"%s STAT PDU has wrong size (%d)",
-		  label,*length);
-		break;
-	    }
-	    len = *length/4;
-	    diag(COMPONENT,DIAG_DEBUG,"%s STAT(PS=%d,MR=%d,R=%d,items=%d:",
-	      label,*ps,*mr,*r,len);
-	    list = (int *) data;
-	    while (len > 1) {
-		diag(COMPONENT,DIAG_DEBUG,"%s    %d..%d",label,ntohl(list[0]),
-		  ntohl(list[1]));
-		list += 2;
-		len -= 2;
-	    }
-	    if (!len)
-		diag(COMPONENT,DIAG_DEBUG,"%s    <last is absent>)",label);
-	    else diag(COMPONENT,DIAG_DEBUG,"%s    <next is> %d)",label,
-		  ntohl(*list));
-	    break;
-	case SSCOP_USTAT:
-	    if (*length != 8) {
-		diag(COMPONENT,DIAG_WARN,"%s USTAT PDU has wrong size (%d)",
-		  label,*length);
-		break;
-	    }
-	    list = (int *) data;
-	    diag(COMPONENT,DIAG_DEBUG,"%s USTAT(MR=%d,R=%d,%d..%d)",label,*mr,
-	      *r,ntohl(list[0]),
-	      ntohl(list[1]));
-	    break;
-	case SSCOP_UD:
-	    diag(COMPONENT,DIAG_DEBUG,"%s UD(len=%d)",label,*length);
-	    break;
-	case SSCOP_MD:
-	    diag(COMPONENT,DIAG_DEBUG,"%s MD(len=%d)",label,*length);
-	    break;
-	case SSCOP_BGN:
-	    diag(COMPONENT,DIAG_DEBUG,"%s BGN(SQ=%d,MR=%d,len=%d)",label,*sq,
-	      *mr,*length);
-	    break;
-	case SSCOP_BGAK:
-	    diag(COMPONENT,DIAG_DEBUG,"%s BGAK(MR=%d,len=%d)",label,*mr,
-	      *length);
-	    break;
-	case SSCOP_BGREJ:
-	    diag(COMPONENT,DIAG_DEBUG,"%s BGREJ(len=%d)",label,*length);
-	    break;
-	case SSCOP_END:
-	    diag(COMPONENT,DIAG_DEBUG,"%s END(S=%d,len=%d)",label,*s,*length);
-	    break;
-	case SSCOP_ENDAK:
-	    diag(COMPONENT,DIAG_DEBUG,"%s ENDAK()",label);
-	    break;
-	case SSCOP_RS:
-	    diag(COMPONENT,DIAG_DEBUG,"%s RS(SQ=%d,MR=%d,len=%d)",label,*sq,
-	      *mr,*length);
-	    break;
-	case SSCOP_RSAK:
-	    diag(COMPONENT,DIAG_DEBUG,"%s RSAK(MR=%d)",label,*mr);
-	    break;
-	case SSCOP_ER:
-	    diag(COMPONENT,DIAG_DEBUG,"%s ER(MR=%d)",label,*mr);
-	    break;
-	case SSCOP_ERAK:
-	    diag(COMPONENT,DIAG_DEBUG,"%s ERAK(MR=%d)",label,*mr);
-	    break;
-	default:
-	    diag(COMPONENT,DIAG_ERROR,"%s unknown PDU type %d\n",label,type);
-    }
-}
-
-
 static int sdu_length(BUFFER *buf)
 {
      return buf->length-4-SSCOP_PAD(*(unsigned long *) ((char *) buf->data+
@@ -261,159 +150,6 @@ static int sdu_length(BUFFER *buf)
 }
 
 
-static int decompose_pdu(SSCOP_DSC *dsc,void *msg,int size,
-  unsigned char *type,int *length,int *s,int *ps,int *r,int *mr,int *sq)
-{
-    unsigned long *last;
-    unsigned char pad;
-    int n;
-
-/*
- * *length is undefined if PDU has no variable-length data part
- */
-
-    if (size < 4 || (size & 3)) {
-	diag(COMPONENT,DIAG_DEBUG,"invalid message length (%d)",size);
-	maa_error(dsc,'U',0);
-	return -1;
-    }
-    last = (unsigned long *) ((char *) msg+size-4);
-    *type = SSCOP_TYPE(*last);
-    pad = SSCOP_PAD(*last);
-    n = SSCOP_N(*last);
-    *length = size-4-pad;
-    switch (*type) {
-	case SSCOP_SD:
-	    *s = n;
-	    break;
-	case SSCOP_POLL:
-	    if (size != 8) {
-		diag(COMPONENT,DIAG_DEBUG,"POLL PDU has bad length (%d)",size);
-		maa_error(dsc,'U',0);
-		return -1;
-	    }
-	    *s = n;
-	    *ps = SSCOP_N(*(unsigned long *) msg);
-	    break;
-	case SSCOP_STAT:
-	    if (size < 12) {
-		diag(COMPONENT,DIAG_DEBUG,"STAT PDU too short (%d)",size);
-		maa_error(dsc,'U',0);
-		return -1;
-	    }
-	    if (*length & 3) {
-		diag(COMPONENT,DIAG_DEBUG,"STAT PDU has bad length (%d)",
-		  length);
-		maa_error(dsc,'U',0);
-		return -1;
-	    }
-	    *r = n;
-	    *mr = SSCOP_N(last[-1]);
-	    *ps = SSCOP_N(last[-2]);
-	    *length -= 8;
-	    break;
-	case SSCOP_USTAT:
-	    if (size != 16) {
-		diag(COMPONENT,DIAG_DEBUG,"USTAT PDU has bad length (%d)",
-		  size);
-		maa_error(dsc,'U',0);
-		return -1;
-	    }
-	    *r = n;
-	    *mr = SSCOP_N(last[-1]);
-	    *length -= 4;
-	    break;
-	case SSCOP_UD:
-	case SSCOP_MD:
-	    break;
-	case SSCOP_BGN:
-	    if (size < 8) {
-		diag(COMPONENT,DIAG_DEBUG,"BGN PDU too short (%d)",size);
-		maa_error(dsc,'U',0);
-		return -1;
-	    }
-	    *mr = n;
-	    *sq = SSCOP_N(last[-1]) & 0xff;
-	    *length -= 4;
-	    break;
-	case SSCOP_BGAK:
-	    if (size < 8) {
-		diag(COMPONENT,DIAG_DEBUG,"BGAK PDU too short (%d)",size);
-		maa_error(dsc,'U',0);
-		return -1;
-	    }
-	    *mr = n;
-	    *length -= 4;
-	    break;
-	case SSCOP_BGREJ:
-	    if (size < 8) {
-		diag(COMPONENT,DIAG_DEBUG,"BGREJ PDU too short (%d)",size);
-		maa_error(dsc,'U',0);
-		return -1;
-	    }
-	    *length -= 4;
-	    break;
-	case SSCOP_END:
-	    if (size < 8) {
-		diag(COMPONENT,DIAG_DEBUG,"END PDU too short (%d)",size);
-		maa_error(dsc,'U',0);
-		return -1;
-	    }
-	    *s = !!(ntohl(*last) & SSCOP_S_BIT);
-	    *length -= 4;
-	    break;
-	case SSCOP_ENDAK:
-	    if (size != 8) {
-		diag(COMPONENT,DIAG_DEBUG,"ENDAK PDU has bad length (%d)",
-		  size);
-		maa_error(dsc,'U',0);
-		if (size < 4) return -1; /* make it work with Fore */
-	    }
-	    break;
-	case SSCOP_RS:
-	    if (size < 8) {
-		diag(COMPONENT,DIAG_DEBUG,"RS PDU too short (%d)",size);
-		maa_error(dsc,'U',0);
-		return -1;
-	    }
-	    *mr = n;
-	    *sq = SSCOP_N(last[-1]) & 0xff;
-	    *length -= 4;
-	    break;
-	case SSCOP_RSAK:
-	    if (size != 8) {
-		diag(COMPONENT,DIAG_DEBUG,"RSAK PDU has bad length (%d)",size);
-		maa_error(dsc,'U',0);
-		return -1;
-	    }
-	    *mr = n;
-	    break;
-	case SSCOP_ER:
-	    if (size != 8) {
-		diag(COMPONENT,DIAG_DEBUG,"ER PDU has bad length (%d)",size);
-		maa_error(dsc,'U',0);
-		return -1;
-	    }
-	    *mr = n;
-	    *sq = SSCOP_N(last[-1]) & 0xff;
-	    break;
-	case SSCOP_ERAK:
-	    if (size != 8) {
-		diag(COMPONENT,DIAG_DEBUG,"ERAK PDU has bad length (%d)",size);
-		maa_error(dsc,'U',0);
-		return -1;
-	    }
-	    *mr = n;
-	    break;
-	default:
-	    diag(COMPONENT,DIAG_DEBUG,"unknown PDU type %d (0x%x)",*type,
-	      *type);
-	    return -1;
-    }
-    return 0;
-}
-
-
 static BUFFER *build_pdu(SSCOP_DSC *dsc,unsigned char type,void *data,
   int num)
 {
@@ -505,7 +241,7 @@ static void emit_pdu(SSCOP_DSC *dsc,BUFFER *buf)
 
 	if (DECOMPOSE_PDU(dsc,buf->data,buf->length))
 	    diag(COMPONENT,DIAG_FATAL,"composed garbage");
-	PRINT_PDU(dsc,"SEND",buf->data);
+	PRINT_PDU("SEND",buf->data);
     }
     if (dsc->ops->cpcs_send)
 	dsc->ops->cpcs_send(dsc->user,buf->data,buf->length);
@@ -1180,7 +916,7 @@ static int handle_sscop_pdu(SSCOP_DSC *dsc,void *msg,int size)
 
     dump_pdu(msg,size);
     if (DECOMPOSE_PDU(dsc,msg,size)) return 1;
-    PRINT_PDU(dsc,"RECV",msg);
+    PRINT_PDU("RECV",msg);
     switch (type) {
 	case SSCOP_UD:
 	    if (dsc->ops->unitdata) dsc->ops->unitdata(dsc->user,msg,length);
@@ -1955,6 +1691,13 @@ void sscop_maa_data(SSCOP_DSC *dsc,void *buffer,int size) /* 20.47-48 */
 
 void start_sscop(SSCOP_DSC *dsc,SSCOP_USER_OPS *ops,void *user_data)
 {
+    static int initialize = 1;
+
+    if (initialize) {
+	pdu_maa = maa_error;
+	pdu_diag = do_diag;
+	initialize = 0;
+    }
     dsc->ops = ops;
     dsc->user = user_data;
     dsc->vt_sq = dsc->vr_sq = 0; /* 20.5 */
