@@ -27,17 +27,12 @@
 #define CONFIG_FILE "/etc/atmsigd.conf"
 
 
-#ifdef MEM_DEBUG
-extern int mpr(void);
-extern int mcheck (void (*)(int));
-#endif
-
 extern int yyparse(void);
 extern FILE *yyin;
 
 int net = 0;
 int debug = 0;
-int pretty = A2T_PRETTY | A2T_NAME;
+int pretty = A2T_PRETTY | A2T_NAME | A2T_LOCAL;
 int sig_pcr = -1; /* obsolete */
 const char *sig_qos = NULL;
 const char *dump_dir = NULL;
@@ -340,10 +335,6 @@ int main(int argc,char **argv)
     char *end;
     int c,background;
 
-#ifdef MEM_DEBUG
-    if (getenv("MCHECK")) mcheck(0);
-    if (mpr() < 0) return 1;
-#endif
     set_application("atmsigd");
     config_file = CONFIG_FILE;
     dump_dir = NULL;
