@@ -58,18 +58,26 @@ static int send_setup(SOCKET *sock)
     q_assign(&dsc,QF_qos_fw,0); /* QOS 0 */
     q_assign(&dsc,QF_qos_bw,0);
     local = NULL;
-    if (sock->local && *sock->local->sas_addr.prv) local = sock->local;
-    else if (local_addr[0].state == ls_same && *local_addr[0].addr.sas_addr.prv)
+    if (sock->local && (*sock->local->sas_addr.prv ||
+      *sock->local->sas_addr.pub)) local = sock->local;
+    else if (local_addr[0].state == ls_same &&
+	  (*local_addr[0].addr.sas_addr.prv ||
+	  *local_addr[0].addr.sas_addr.pub))
 	    local = &local_addr[0].addr;
-    /* @@@ handle E.164 too */
     if (!local) {
 	if (!error) error = -EADDRNOTAVAIL;
     }
-    else {
-	q_assign(&dsc,QF_cgpn_plan,ATM_NP_NSAP);
-	q_assign(&dsc,QF_cgpn_type,ATM_TON_UNKNOWN);
-	q_write(&dsc,QF_cgpn,(void *) local->sas_addr.prv,ATM_ESA_LEN);
-    }
+    else if (*sock->local->sas_addr.pub) {
+	    q_assign(&dsc,QF_cgpn_plan,ATM_NP_E164);
+	    q_assign(&dsc,QF_cgpn_type,ATM_TON_INTRNTNL);
+	    q_write(&dsc,QF_cgpn,(void *) local->sas_addr.pub,
+	      strlen(local->sas_addr.pub));
+	}
+	else {
+	    q_assign(&dsc,QF_cgpn_plan,ATM_NP_NSAP);
+	    q_assign(&dsc,QF_cgpn_type,ATM_TON_UNKNOWN);
+	    q_write(&dsc,QF_cgpn,(void *) local->sas_addr.prv,ATM_ESA_LEN);
+	}
     if (net) {
 	int vci;
 
@@ -154,6 +162,9 @@ static void dispatch(SOCKET *sock,struct atmsvc_msg *msg)
 		for (walk = local_addr; walk->state != ls_unused; walk++)
 		    if (walk->state == ls_same && atm_equal(&walk->addr,
 		      &msg->svc,(ATM_ESA_LEN-1)*8,AXE_WILDCARD)) break;
+		    if(*msg->svc.sas_addr.pub)
+			diag(COMPONENT,DIAG_DEBUG,"binding to E.164 address "
+			  "%s\n",msg->svc.sas_addr.pub);
 		if (walk->state == ls_unused)
 		    SEND_ERROR(msg->vcc,-EADDRNOTAVAIL);
 		else send_kernel(msg->vcc,0,as_okay,0,NULL,NULL,NULL,NULL);
