@@ -67,9 +67,20 @@ static void setup_call(unsigned long call_ref)
     SOCKET *sock,*this,**walk;
     struct sockaddr_atmsvc *sap,*new_sap;
     struct atm_qos qos,new_qos;
-    unsigned char buf[ATM_ESA_LEN];
-    int len,i;
+    unsigned char buf[ATM_ESA_LEN]; /* max(ATM_ESA_LEN,ATM_E164_LEN) */
+    int addr_loc,len,i;
 
+    switch (q_fetch(&in_dsc,QF_cgpn_plan)) {
+	case ATM_NP_E164:
+	    addr_loc = QF_cdpn_e164;
+	    break;
+	case ATM_NP_NSAP:
+	    addr_loc = QF_cdpn_esa;
+	    break;
+	default:
+	    send_release_complete(call_ref,ATM_CV_UNALLOC);
+	    return;
+    }
     sap = sap_decode(&in_dsc,&qos);
     new_sap = NULL;
     sock = lookup_sap(sap,&qos,&new_sap,&new_qos);
@@ -103,7 +114,7 @@ static void setup_call(unsigned long call_ref)
     this->qos = new_qos;
     /* if (sock->local) *this->local->sas_addr = sock->local->sas_addr; ??? */
     diag(COMPONENT,DIAG_DEBUG,"AAL type %ld",q_fetch(&in_dsc,QF_aal_type));
-    len = q_read(&in_dsc,QF_cdpn_esa,(void *) &buf,sizeof(buf));
+    len = q_read(&in_dsc,addr_loc,(void *) &buf,sizeof(buf));
     if (debug) {
 	printf("Addr len %d:",len);
 	for (i = 0; i < (len < 30 ? len : 30); i++) printf(" %02X",buf[i]);
@@ -123,14 +134,30 @@ static void setup_call(unsigned long call_ref)
     memset(this->remote,0,sizeof(struct sockaddr_atmsvc));
     if (q_present(&in_dsc,QF_cgpn)) { /* should handle E.164 too */
 	char buffer[MAX_ATM_ADDR_LEN+1];
+	int plan;
 
-	this->remote->sas_family = AF_ATMSVC;
-	i = q_read(&in_dsc,QF_cgpn,(void *) this->remote->sas_addr.prv,
-	  ATM_ESA_LEN);
-	/*printf("addr_len = %d\n",i);*/
-	if (atm2text(buffer,MAX_ATM_ADDR_LEN+1,(struct sockaddr *) this->remote,
-	  pretty) < 0) strcpy(buffer,"<invalid address>");
-	diag(COMPONENT,DIAG_DEBUG,"Incoming call from %s",buffer);
+	plan = q_fetch(&in_dsc,QF_cgpn_plan);
+	switch (plan) {
+	    case ATM_NP_NSAP:
+		i = q_read(&in_dsc,QF_cgpn,(void *) this->remote->sas_addr.prv,
+		  ATM_ESA_LEN);
+		break;
+	    case ATM_NP_E164:
+		i = q_read(&in_dsc,QF_cgpn,(void *) this->remote->sas_addr.pub,
+		  ATM_E164_LEN);
+		break;
+	    default:
+		diag(COMPONENT,DIAG_WARN,"Ignoring cgpn with unrecognized "
+		  "numbering plan 0x%x\n",plan);
+		i = 0;
+	}
+	if (i) {
+	    this->remote->sas_family = AF_ATMSVC;
+	    if (atm2text(buffer,MAX_ATM_ADDR_LEN+1,
+	      (struct sockaddr *) this->remote,pretty) < 0)
+		strcpy(buffer,"<invalid address>");
+	    diag(COMPONENT,DIAG_DEBUG,"Incoming call from %s",buffer);
+	}
     }
     send_kernel(0,sock->id,as_indicate,0,&this->pvc,this->remote,NULL,&new_qos);
     for (walk = &sock->listen; *walk; walk = &(*walk)->listen);
